@@ -31,14 +31,14 @@ sub parse_cookie_from_env {
     return {} unless defined $env_str;
 
     my $cookies = {};
-    foreach my $cookie ( split( /[,;]\s/, $env_str ) ) {
+    foreach my $cookie ( split( /[,;]\s?/, $env_str ) ) {
         # here, we don't want more than the 2 first elements
         # a cookie string can contains something like:
         # cookie_name="foo=bar"
         # we want `cookie_name' as the value and `foo=bar' as the value
         my( $name,$value ) = split(/\s*=\s*/, $cookie, 2);
         my @values;
-        if ( $value ne '' ) {
+        if ( defined $value && $value ne '' ) {
             @values = map { uri_unescape($_) } split( /[&;]/, $value );
         }
         $cookies->{$name} =
@@ -63,8 +63,7 @@ sub set_cookie {
 
 sub set_cookie_object {
     my ($class, $name, $cookie) = @_;
-    Dancer::SharedData->response->push_header(
-        'Set-Cookie' => $cookie->to_header);
+    Dancer::SharedData->response->add_cookie($name, $cookie);
     Dancer::Cookies->cookies->{$name} = $cookie;
 }
 
