@@ -1,8 +1,5 @@
 package Dancer::Object::Singleton;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: Singleton base class for Dancer
-$Dancer::Object::Singleton::VERSION = '1.3514_04'; # TRIAL
-$Dancer::Object::Singleton::VERSION = '1.351404';
+
 # This class is a root class for singleton objects in Dancer.
 # It provides basic OO singleton tools for Perl5 without being... MooseX::Singleton ;-)
 
@@ -65,18 +62,10 @@ sub _setter_code {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Object::Singleton - Singleton base class for Dancer
 
-=head1 VERSION
-
-version 1.3514_04
-
 =head1 SYNOPSIS
 
     package My::Dancer::Extension;
@@ -99,7 +88,7 @@ version 1.3514_04
 
 =head1 DESCRIPTION
 
-Dancer::Object::Singleton is meant to be used instead of Dancer::Object, if you
+Dancer::Object::Singleton is meantto be used instead of Dancer::Object, if you
 want your object to be a singleton, that is, a class that has only one instance
 in the application.
 
@@ -129,13 +118,15 @@ C<get_attributes>.
 
 =head1 AUTHOR
 
-Dancer Core Developers
+Damien Krotkine
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-This software is copyright (c) 2010 by Alexis Sukrieh.
+Copyright 2010 Damien Krotkine.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
 
-=cut
