@@ -98,7 +98,7 @@ sub get_action_response {
     my $app = ($handler && $handler->app) ? $handler->app : Dancer::App->current();
 
     # run the before filters, before "running" the route handler
-    Dancer::Factory::Hook->instance->execute_hooks('before');
+    Dancer::Factory::Hook->instance->execute_hooks('before', $handler);
 
     # recurse if something has changed
     my $MAX_RECURSIVE_LOOP = 10;
@@ -149,6 +149,45 @@ sub get_action_response {
     }
 }
 
+sub render_autopage {
+    return unless Dancer::setting('auto_page');
+
+    my $request = Dancer::SharedData->request;
+    my $path = $request->path_info;
+
+    # See if we find a matching view for this request, if so, render it
+    my $viewpath = $path;
+    $viewpath =~ s{^/}{};
+    my $view = Dancer::engine('template')->view($viewpath) || '';
+
+    if ($view && -f $view) {
+        # A view exists for the path requested, go ahead and render it:
+        return _autopage_response($viewpath);
+    }
+
+    # Try appending "index" and looking again
+    $view = Dancer::engine('template')->view(
+        Dancer::FileUtils::path($viewpath, 'index')
+    )|| '';
+    Dancer::error("Looking for $viewpath/index - got $view");
+    if ($view && -f $view) {
+        return _autopage_response(
+            Dancer::FileUtils::path($viewpath, 'index')
+        );
+    }
+
+    return;
+}
+sub _autopage_response {
+    my $viewpath = shift;
+    my $response = Dancer::Response->new;
+    $response->status(200);
+    $response->content(
+        Dancer::template($viewpath)
+    );
+    return $response;
+}
+
 sub serialize_response_if_needed {
     my $response = Dancer::SharedData->response();
 
@@ -180,11 +219,15 @@ sub get_file_response {
 
     my $app = Dancer::App->current;
     # TODO: this should be later removed with a check whether the file exists
-    # and then returning a 404, path_or_empty should be removed
-    my $static_file = path_or_empty( $app->setting('public'), $path_info );
+    # and then returning a 404
+    my $public = defined $app->setting('public') ?
+                 $app->setting('public')         :
+                 '';
+
+    my $static_file = path( $public, $path_info );
 
     return if ( !$static_file
-        || index( $static_file, path( $app->setting('public') ) ) != 0 );
+        || index( $static_file, ( path($public) || '' ) ) != 0 );
 
     return Dancer::Renderer->get_file_response_for_path( $static_file, undef,
         $request->content_type );
