@@ -5,12 +5,12 @@ use warnings;
 use Carp;
 use base 'Dancer::Session::Abstract';
 
+use Fcntl ':flock';
 use Dancer::Logger;
 use Dancer::ModuleLoader;
 use Dancer::Config 'setting';
 use Dancer::FileUtils qw(path set_file_mode);
-use File::Copy;
-use File::Temp qw(tempfile);
+use Dancer::Exception qw(:all);
 
 # static
 
@@ -21,7 +21,7 @@ sub init {
     $self->SUPER::init(@_);
 
     if (!keys %session_dir_initialized) {
-        croak "YAML is needed and is not installed"
+        raise core_session => "YAML is needed and is not installed"
           unless Dancer::ModuleLoader->load('YAML');
     }
 
@@ -35,7 +35,7 @@ sub init {
         # make sure session_dir exists
         if (!-d $session_dir) {
             mkdir $session_dir
-              or croak "session_dir $session_dir cannot be created";
+              or raise core_session => "session_dir $session_dir cannot be created";
         }
         Dancer::Logger::core("session_dir : $session_dir");
     }
@@ -60,9 +60,16 @@ sub reset {
 # Return the session object corresponding to the given id
 sub retrieve {
     my ($class, $id) = @_;
+    my $session_file = yaml_file($id);
 
-    return unless -f yaml_file($id);
-    return YAML::LoadFile(yaml_file($id));
+    return unless -f $session_file;
+
+    open my $fh, '+<', $session_file or die "Can't open '$session_file': $!\n";
+    flock $fh, LOCK_EX or die "Can't lock file '$session_file': $!\n";
+    my $content = YAML::LoadFile($fh);
+    close $fh or die "Can't close '$session_file': $!\n";
+
+    return $content;
 }
 
 # instance
@@ -72,11 +79,6 @@ sub yaml_file {
     return path(setting('session_dir'), "$id.yml");
 }
 
-sub tmp_yaml_file {
-    my ($id) = @_;
-    return path(setting('session_dir'), "$id.tmp");
-}
-
 sub destroy {
     my ($self) = @_;
     use Dancer::Logger;
@@ -86,13 +88,15 @@ sub destroy {
 }
 
 sub flush {
-    my $self = shift;
-    my ( $fh, $tmpname ) =
-      tempfile( $self->id . '.XXXXXXXX', DIR => setting('session_dir') );
+    my $self         = shift;
+    my $session_file = yaml_file( $self->id );
+
+    open my $fh, '>', $session_file or die "Can't open '$session_file': $!\n";
+    flock $fh, LOCK_EX or die "Can't lock file '$session_file': $!\n";
     set_file_mode($fh);
     print {$fh} YAML::Dump($self);
-    close $fh;
-    move($tmpname, yaml_file($self->id));
+    close $fh or die "Can't close '$session_file': $!\n";
+
     return $self;
 }
 
