@@ -3,7 +3,6 @@ package Dancer::Template::Abstract;
 use strict;
 use warnings;
 use Carp;
-use Clone;
 
 use Dancer::Logger;
 use Dancer::Factory::Hook;
@@ -146,18 +145,18 @@ sub _prepare_tokens_options {
     $tokens ||= {};
     $tokens->{perl_version}   = $];
     $tokens->{dancer_version} = $Dancer::VERSION;
-    $tokens->{settings}       = Clone::clone(Dancer::Config->settings);
+    $tokens->{settings}       = Dancer::Config->settings;
 
     # If we're processing a request, also add the request object, params and
     # vars as tokens:
     if (my $request = Dancer::SharedData->request) {
         $tokens->{request}        = $request;
-        $tokens->{params}         = Clone::clone($request->params);
-        $tokens->{vars}           = Clone::clone(Dancer::SharedData->vars);
+        $tokens->{params}         = $request->params;
+        $tokens->{vars}           = Dancer::SharedData->vars;
     }
 
     Dancer::App->current->setting('session')
-      and $tokens->{session} = Clone::clone(Dancer::Session->get);
+      and $tokens->{session} = Dancer::Session->get;
 
     return ($tokens, $options);
 }
@@ -311,17 +310,6 @@ system with multiple document roots (like L<Text::XSlate> or
 L<Template>), you can override this method to always return true, and
 therefore skip this check.
 
-=item B<view_exists($view_path)>
-
-By default, Dancer::Template::Abstract checks to see if it can find the
-view file calling C<view_exists($path_to_file)>. If not, it will
-generate a nice error message for the user.
-
-If you are using extending Dancer::Template::Abstract to use a template
-system with multiple document roots (like L<Text::XSlate> or
-L<Template>), you can override this method to always return true, and
-therefore skip this check.
-
 =item B<layout($layout, $tokens, $content)>
 
 The default behavior of this method is to merge a content with a layout.  The
